==> debug-level-2.0.2.tgz: package/lib/browser.js <==
"use strict";

var _asyncc = require("asyncc");

var _ms = _interopRequireDefault(require("ms"));

var _utils = require("./utils");

var _LogBase = _interopRequireDefault(require("./LogBase.js"));

var _wrapConsole = _interopRequireDefault(require("./wrapConsole.js"));

var _err = _interopRequireDefault(require("./serializers/err.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var COLOR_RESET = 'color:inherit';
/**
 * global log options
 */

var options = {
  level: _utils.WARN,
  namespaces: undefined,
  colors: true,
  // apply coloring to browser console
  url: undefined // [optional] url to report errors

};
/**
 * get storage
 * @private
 */

var storage = function storage() {
  try {
    return typeof chrome !== 'undefined' && typeof chrome.storage !== 'undefined' ? chrome.storage.local : window.localStorage;
  } catch (err) {
    // istanbul ignore next
    return {};
  }
};
/**
 * check if console colors are supported
 * @copyright debug contributors
 * @see https://github.com/visionmedia/debug
 * @private
 */


var supportsColors = function supportsColors() {
  var tmp;
  var userAgent = typeof navigator !== 'undefined' && navigator.userAgent; // NB: In an Electron preload script, document will be defined but not fully
  // initialized. Since we know we're in Chrome, we'll just detect this case
  // explicitly

  var isElectron = typeof window !== 'undefined' && (tmp = window.process) && tmp.type === 'renderer'; // is webkit? http://stackoverflow.com/a/16459606/376773
  // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632

  var isReactNative = typeof document !== 'undefined' && (tmp = document.documentElement) && (tmp = tmp.style) && tmp.WebkitAppearance; // is firebug? http://stackoverflow.com/a/398120/376773

  var isFireBug = typeof window !== 'undefined' && (tmp = window.console) && (tmp.firebug || tmp.exception && tmp.table);

  if (isElectron) {
    // istanbul ignore next
    return true;
  } // Internet Explorer and Edge do not support colors.


  if (/(edge|trident)\/(\d+)/i.exec(userAgent)) {
    // istanbul ignore next
    return false;
  }

  return !!(isReactNative || isFireBug || // is firefox >= v31?
  // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
  /firefox\/(\d+)/i.exec(userAgent) && parseInt(RegExp.$1, 10) >= 31 || // double check webkit in userAgent just in case we are in a worker
  /applewebkit\/(\d+)/i.exec(userAgent));
};
/**
 * creates a new logger for the browser
 * @constructor
 * @param {String} name - namespace of Logger
 */


function Log(name, opts) {
  if (!(this instanceof Log)) return new Log(name, opts);

  var _storage = storage();

  Object.assign(options, (0, _utils.inspectOpts)(_storage), (0, _utils.inspectNamespaces)(_storage));
  options.colors = options.colors === false ? false : supportsColors();
  var serializers = Object.assign({}, options.serializers, opts && opts.serializers);

  _LogBase["default"].call(this, name, Object.assign({}, options, opts, {
    serializers: serializers
  }));

  var colorFn = function colorFn(c) {
    return "color:".concat(c);
  };

  this.color = (0, _utils.selectColor)(name, colorFn);
  this.levColors = (0, _utils.levelColors)(colorFn);
  this.queue = new _asyncc.Queue(this._sendLog.bind(this), 3);
}

Object.setPrototypeOf(Log.prototype, _LogBase["default"].prototype);
Object.assign(Log.prototype, {
  /**
   * render arguments to console.log
   * @public
   * @param {Array} args - console.log arguments
   * @param {String} level - level of log line (might be used for custom Logger which uses different streams per level)
   * @return {String}
   */
  render: function render(args) {
    var _console;

    (_console = console).log.apply(_console, _toConsumableArray(args)); // eslint-disable-line no-console


    return args;
  },

  /**
   * send log to server
   * @param {String|Object} level - log level
   * @param {String|Any} fmt - log level
   * @param {Array} args - log arguments
   */
  send: function send(level, fmt, args) {
    var obj;

    if (_typeof(level) === 'object') {
      obj = level;
    } else {
      var uns = this._formatJson(level, fmt, args);

      obj = this._applySerializers(uns);
    }

    obj.userAgent = navigator.userAgent;
    var str = this.formatter.stringify(obj);
    this.queue.push(str);
  },

  /**
   * format log arguments
   * @private
   */
  _log: function _log(level, fmt, args) {
    var uns = this._formatJson(level, fmt, args);

    var obj = this._applySerializers(uns);

    var _args = this._format(obj);

    var res = this.render(_args, level);

    if (this.opts.url) {
      this.send(obj);
    }

    return res;
  },

  /**
   * format arguments for console.log
   * @private
   * @return {Array} args for console.log
   */
  _format: function _format(_ref) {
    var level = _ref.level,
        name = _ref.name,
        time = _ref.time,
        _ref$msg = _ref.msg,
        msg = _ref$msg === void 0 ? '' : _ref$msg,
        diff = _ref.diff,
        other = _objectWithoutProperties(_ref, ["level", "name", "time", "msg", "diff"]);

    var color = this.color;
    var args = [];
    var hasOther = Object.keys(other).length;
    args[0] = [this._color(level), this._color(name), msg, hasOther ? '%O' : undefined, this._color('+' + (0, _ms["default"])(diff))].filter(function (s) {
      return s !== undefined;
    }).join(' ');
    if (hasOther) args.push(other);

    if (this.opts.colors) {
      args.splice(1, 0, color + ';font-weight:bold', COLOR_RESET);
      args.splice(1, 0, this.levColors[level], COLOR_RESET);
    }

    if (this.opts.colors) {
      var idx = 0;
      var lastC;
      args[0].replace(/%([a-zA-Z%])/g, function (match, format) {
        idx++;

        if (format === 'c') {
          lastC = idx;
        }

        return match;
      });
      args.splice(lastC - 1, 0, color, COLOR_RESET);
    }

    return args;
  },

  /**
   * transfer log to server via zero pixel image request
   */
  _sendLog: function _sendLog(str, cb) {
    var img = new Image();

    var done = function done() {
      return cb();
    };

    img.onload = done;
    img.onerror = done;
    img.onabort = done;
    img.src = this.opts.url + '/0.gif?id=' + (0, _utils.random)(6) + '&log=' + encodeURIComponent(str);
  },

  /**
   * Add colors, style to string
   * @private
   */
  _color: function _color(str) {
    return this.opts.colors ? "%c".concat(str, "%c") : str;
  }
});
/**
 * Apply (and get) global options
 * @param {object} [opts] - changed options
 * @return {object} global options
 */

Log.options = function (opts) {
  if (!opts) return Object.assign({}, options);
  Object.assign(options, opts, {
    colors: opts.colors === false ? false : supportsColors()
  });
  return options;
};
/**
 * save options in `localStorage`
 */


Log.save = function () {
  var _storage = storage();

  Log.reset();
  (0, _utils.saveOpts)(_storage, options);
};
/**
 * reset saved options
 */


Log.reset = function () {
  var _storage = storage();

  Object.keys(_storage).forEach(function (key) {
    if (/^(DEBUG|DEBUG_.*)$/i.test(key)) {
      _storage.removeItem(key);
    }
  });
};
/**
 * wrap console logging functions like
 * console.log, console.info, console.warn, console.error
 * @param {string} [name='console']
 * @param {object} opts - see Log.options
 * @param {string} [opts.level4log='log'] - log level for console.log
 * @return {function} unwrap function
 */


Log.wrapConsole = function () {
  var name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'console';
  var opts = arguments.length > 1 ? arguments[1] : undefined;
  var log = new Log(name, opts);
  return (0, _wrapConsole["default"])(log, opts);
};

Log.serializers = {
  err: _err["default"]
};
module.exports = Log;

==> debug-level-2.1.1.tgz: package/lib/browser.js <==
"use strict";

var _asyncc = require("asyncc");

var _ms = _interopRequireDefault(require("ms"));

var _utils = require("./utils");

var _LogBase = _interopRequireDefault(require("./LogBase.js"));

var _wrapConsole = _interopRequireDefault(require("./wrapConsole.js"));

var _err = _interopRequireDefault(require("./serializers/err.js"));

var _excluded = ["level", "name", "time", "msg", "diff"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var COLOR_RESET = 'color:inherit';
/**
 * global log options
 */

var options = {
  level: _utils.WARN,
  namespaces: undefined,
  colors: true,
  // apply coloring to browser console
  url: undefined // [optional] url to report errors

};
/**
 * get storage
 * @private
 */

var storage = function storage() {
  try {
    return typeof chrome !== 'undefined' && typeof chrome.storage !== 'undefined' ? chrome.storage.local : window.localStorage;
  } catch (err) {
    // istanbul ignore next
    return {};
  }
};
/**
 * check if console colors are supported
 * @copyright debug contributors
 * @see https://github.com/visionmedia/debug
 * @private
 */


var supportsColors = function supportsColors() {
  var tmp;
  var userAgent = typeof navigator !== 'undefined' && navigator.userAgent; // NB: In an Electron preload script, document will be defined but not fully
  // initialized. Since we know we're in Chrome, we'll just detect this case
  // explicitly

  var isElectron = typeof window !== 'undefined' && (tmp = window.process) && tmp.type === 'renderer'; // is webkit? http://stackoverflow.com/a/16459606/376773
  // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632

  var isReactNative = typeof document !== 'undefined' && (tmp = document.documentElement) && (tmp = tmp.style) && tmp.WebkitAppearance; // is firebug? http://stackoverflow.com/a/398120/376773

  var isFireBug = typeof window !== 'undefined' && (tmp = window.console) && (tmp.firebug || tmp.exception && tmp.table);

  if (isElectron) {
    // istanbul ignore next
    return true;
  } // Internet Explorer and Edge do not support colors.


  if (/(edge|trident)\/(\d+)/i.exec(userAgent)) {
    // istanbul ignore next
    return false;
  }

  return !!(isReactNative || isFireBug || /firefox\/(\d+)/i.exec(userAgent) && parseInt(RegExp.$1, 10) >= 31 || /applewebkit\/(\d+)/i.exec(userAgent));
};
/**
 * creates a new logger for the browser
 * @constructor
 * @param {String} name - namespace of Logger
 */


function Log(name, opts) {
  if (!(this instanceof Log)) return new Log(name, opts);

  var _storage = storage();

  Object.assign(options, (0, _utils.inspectOpts)(_storage), (0, _utils.inspectNamespaces)(_storage));
  options.colors = options.colors === false ? false : supportsColors();
  var serializers = Object.assign({}, options.serializers, opts && opts.serializers);

  _LogBase["default"].call(this, name, Object.assign({}, options, opts, {
    serializers: serializers
  }));

  var colorFn = function colorFn(c) {
    return "color:".concat(c);
  };

  this.color = (0, _utils.selectColor)(name, colorFn);
  this.levColors = (0, _utils.levelColors)(colorFn);
  this.queue = new _asyncc.Queue(this._sendLog.bind(this), 3);
}

Object.setPrototypeOf(Log.prototype, _LogBase["default"].prototype);
Object.assign(Log.prototype, {
  /**
   * render arguments to console.log
   * @public
   * @param {Array} args - console.log arguments
   * @param {String} level - level of log line (might be used for custom Logger which uses different streams per level)
   * @return {String}
   */
  render: function render(args) {
    var _console;

    (_console = console).log.apply(_console, _toConsumableArray(args)); // eslint-disable-line no-console


    return args;
  },

  /**
   * send log to server
   * @param {String|Object} level - log level
   * @param {String|Any} fmt - log level
   * @param {Array} args - log arguments
   */
  send: function send(level, fmt, args) {
    var obj;

    if (_typeof(level) === 'object') {
      obj = level;
    } else {
      var uns = this._formatJson(level, fmt, args);

      obj = this._applySerializers(uns);
    }

    obj.userAgent = navigator.userAgent;
    var str = this.formatter.stringify(obj);
    this.queue.push(str);
  },

  /**
   * format log arguments
   * @private
   */
  _log: function _log(level, fmt, args) {
    var uns = this._formatJson(level, fmt, args);

    var obj = this._applySerializers(uns);

    var _args = this._format(obj);

    var res = this.render(_args, level);

    if (this.opts.url) {
      this.send(obj);
    }

    return res;
  },

  /**
   * format arguments for console.log
   * @private
   * @return {Array} args for console.log
   */
  _format: function _format(_ref) {
    var level = _ref.level,
        name = _ref.name,
        time = _ref.time,
        _ref$msg = _ref.msg,
        msg = _ref$msg === void 0 ? '' : _ref$msg,
        diff = _ref.diff,
        other = _objectWithoutProperties(_ref, _excluded);

    var color = this.color;
    var args = [];
    var hasOther = Object.keys(other).length;
    args[0] = [this._color(level), this._color(name), msg, hasOther ? '%O' : undefined, this._color('+' + (0, _ms["default"])(diff))].filter(function (s) {
      return s !== undefined;
    }).join(' ');
    if (hasOther) args.push(other);

    if (this.opts.colors) {
      args.splice(1, 0, color + ';font-weight:bold', COLOR_RESET);
      args.splice(1, 0, this.levColors[level], COLOR_RESET);
    }

    if (this.opts.colors) {
      var idx = 0;
      var lastC;
      args[0].replace(/%([a-zA-Z%])/g, function (match, format) {
        idx++;

        if (format === 'c') {
          lastC = idx;
        }

        return match;
      });
      args.splice(lastC - 1, 0, color, COLOR_RESET);
    }

    return args;
  },

  /**
   * transfer log to server via zero pixel image request
   */
  _sendLog: function _sendLog(str, cb) {
    var img = new Image();

    var done = function done() {
      return cb();
    };

    img.onload = done;
    img.onerror = done;
    img.onabort = done;
    img.src = this.opts.url + '/0.gif?id=' + (0, _utils.random)(6) + '&log=' + encodeURIComponent(str);
  },

  /**
   * Add colors, style to string
   * @private
   */
  _color: function _color(str) {
    return this.opts.colors ? "%c".concat(str, "%c") : str;
  }
});
/**
 * Apply (and get) global options
 * @param {object} [opts] - changed options
 * @return {object} global options
 */

Log.options = function (opts) {
  if (!opts) return Object.assign({}, options);
  Object.assign(options, opts, {
    colors: opts.colors === false ? false : supportsColors()
  });
  return options;
};
/**
 * save options in `localStorage`
 */


Log.save = function () {
  var _storage = storage();

  Log.reset();
  (0, _utils.saveOpts)(_storage, options);
};
/**
 * reset saved options
 */


Log.reset = function () {
  var _storage = storage();

  Object.keys(_storage).forEach(function (key) {
    if (/^(DEBUG|DEBUG_.*)$/i.test(key)) {
      _storage.removeItem(key);
    }
  });
};
/**
 * wrap console logging functions like
 * console.log, console.info, console.warn, console.error
 * @param {string} [name='console']
 * @param {object} opts - see Log.options
 * @param {string} [opts.level4log='log'] - log level for console.log
 * @return {function} unwrap function
 */


Log.wrapConsole = function () {
  var name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'console';
  var opts = arguments.length > 1 ? arguments[1] : undefined;
  var log = new Log(name, opts);
  return (0, _wrapConsole["default"])(log, opts);
};

Log.serializers = {
  err: _err["default"]
};
module.exports = Log;
